List of contributors
--------------------

- `@drvinceknight <https://github.com/drvinceknight>`_
- `@11michalis11 <https://github.com/11michalis11>`_
- `@asinghgaba <https://github.com/asinghgaba>`_
- `@katiemcgoldrick <https://github.com/katiemcgoldrick>`_
- `@volume-on-max <https://github.com/volume-on-max>`_
- `@theref <https://github.com/theref>`_
- `@robert-szeto <https://github.com/robert-szeto>`_
- `@arwheel <https://github.com/arwheel>`_
- Computing for Mathematics class of 2023
